The unified diff between revisions [6cba104d..] and [c8f87fcb..] is displayed below. It can also be downloaded as a raw diff.

This diff has been restricted to the following files: 'database.hh'

#
#
# patch "database.hh"
#  from [c872c9417db96a5ff8d11bf106a094edda699534]
#    to [a3233d1208caea06b3ea1cf5e0b9d53079ebd012]
#
============================================================
--- database.hh	c872c9417db96a5ff8d11bf106a094edda699534
+++ database.hh	a3233d1208caea06b3ea1cf5e0b9d53079ebd012
@@ -243,10 +243,10 @@ public:
   void put_file(file_id const & new_id,
                 file_data const & dat);

   // store new version and update old version to be a delta
   void put_file_version(file_id const & old_id,
                         file_id const & new_id,
-                        file_delta const & del);
+                        file_data const & dat);

   // get plain version if it exists, or reconstruct version
   // from deltas (if they exist).
@@ -243,10 +243,10 @@ public:
                 file_data const & dat);

-  // store new version and update old version to be a delta
+  // store delta to new data. can be called
   void put_file_version(file_id const & old_id,
                         file_id const & new_id,